import router from './router'
import store from './store'
import { cookie } from '@/utils/cookie'
import { MessageBox } from 'element-ui'
import NProgress from 'nprogress' // Progress 进度条
import 'nprogress/nprogress.css'// Progress 进度条样式

function admit(route, routerList) {
  if (route.name && route.meta) {
    return routerList.some(routerItem => {
      if (routerItem.children && routerItem.children.length) {
        return admit(route, routerItem.children)
      } else {
        return routerItem.name === route.name
      }
    })
  } else {
    return true
  }
}

if (process.env.NODE_ENV === 'production') {
  store.dispatch('setRouters', store.getters.roleList).then(() => {
    router.addRoutes(store.getters.addRouters)
  })
} else {
  store.dispatch('setRouters', store.getters.depRoleList).then(() => {
    router.addRoutes(store.getters.addRouters)
  })
}

if (!cookie.get_xToken() || !cookie.get_aesKey()) {
  router.push('login')
}

router.beforeEach((to, from, next) => {
  NProgress.start()
  if (cookie.get_xToken() && cookie.get_aesKey()) {
    if (to.path === '/login') {
      next({ path: '/' })
      NProgress.done() // if current page is home will not trigger	afterEach hook, so manually handle it
    } else {
      if (process.env.NODE_ENV === 'production' && admit(to, store.getters.routers)) {
        next()
      } else if (process.env.NODE_ENV !== 'production' && admit(to, store.getters.routers)) {
        next()
      } else {
        next({ path: '/401', replace: true, query: { noGoBack: true }})
      }
    }
  } else {
    if (store.getters.RouterWhiteList.indexOf(to.path) !== -1) { // 在免登录白名单，直接进入
      next()
    } else {
      if (from.path === '/') {
        next('/login')
      } else if (from.path === '/login') {
        location.reload()
      } else {
        MessageBox.confirm('您当前未登录或登录状态已过期，可以取消继续留在该页面，或者重新登录。', '重新登录', {
          confirmButtonText: '重新登录',
          cancelButtonText: '取消',
          type: 'warning'
        }).then(() => {
          next('/login')
          NProgress.done()
        }).catch(() => {
          NProgress.done()
        })
      }
    }
  }
})

router.afterEach(() => {
  NProgress.done() // 结束Progress
})
