import Vue from 'vue'
import Router from 'vue-router'
const _import = require('./_import_' + process.env.NODE_ENV)

// in development-env not use lazy-loading, because lazy-loading too many pages will cause webpack hot update too slow. so only in production use lazy-loading;
// detail: https://panjiachen.github.io/vue-element-admin-site/#/lazy-loading

Vue.use(Router)

/* Layout */
import Layout from '@/views/layout/Layout'

/**
* hidden: true                   if `hidden:true` will not show in the sidebar(default is false)
* alwaysShow: true               if set true, will always show the root menu, whatever its child routes length
* ignoreRule: true               无视规则添加进权限,显示在侧边栏
*                                if not set alwaysShow, only more than one route under the children
*                                it will becomes nested mode, otherwise not show the root menu
* redirect: noredirect           if `redirect:noredirect` will no redirct in the breadcrumb
* name:'router-name'             the name is used by <keep-alive> (must set!!!)
* meta : {
    title: 'title'               the name show in submenu and breadcrumb (recommend set)
    icon: 'svg-name'             the icon show in the sidebar,
  }
**/
// 不需要权限的页面
export const constantRouterMap = [
  {
    path: '/login',
    hidden: true,
    component: _import('login/index')
  }, {
    path: '/401',
    hidden: true,
    component: _import('errorPage/401')
  }, {
    path: '/404',
    hidden: true,
    component: _import('errorPage/404')
  }, {
    path: '',
    component: Layout,
    redirect: 'home',
    children: [{
      path: 'home',
      name: 'home',
      component: _import('home/index'),
      meta: { title: '首页', icon: 'home_fill' }
    }]
  }, {
    path: '/order',
    component: Layout,
    // alwaysShow: true,
    redirect: 'noredirect',
    name: 'order',
    meta: { title: '订单管理', icon: 'tab' },
    children: [
      { path: 'search',
        name: 'orderSearch',
        component: _import('order/orderSearch'),
        meta: { title: '订单查询', icon: 'search' }
      }
    ]
  }
]

export const asyncRouterMap = [
  {
    path: '/yaWei',
    component: Layout,
    name: 'yaWei',
    redirect: 'noredirect',
    meta: { title: '操作管理', icon: 'example' },
    children: [
      { path: 'search',
        name: 'yaWeiSearch',
        component: _import('yaWei/YaWeiSearch'),
        meta: { title: '押位搜索', icon: 'search' }
      }, {
        path: 'order',
        name: 'yaWeiOrder',
        component: _import('yaWei/YaWeiOrder'),
        meta: { title: '押位订单', icon: 'table' }
      }, {
        path: 'account',
        name: 'yaWeiAccount',
        component: _import('yaWei/YaWeiAccount'),
        meta: { title: '押位账号', icon: 'peoples' }
      }
    ]
  }, {
    path: '/user',
    component: Layout,
    redirect: '/user/userControl',
    name: 'user',
    meta: { title: '用户权限', icon: 'addressbook_fill' },
    children: [{
      path: 'userControl',
      name: 'userControl',
      component: _import('user/UserControl'),
      meta: { title: '用户管理', icon: 'peoples' }
    }, {
      path: 'roleControl',
      name: 'roleControl',
      component: _import('user/RoleControl'),
      meta: { title: '角色管理', icon: 'head_portrait' }
    }, {
      path: 'accessControl',
      name: 'accessControl',
      component: _import('user/AccessControl'),
      meta: { title: '权限管理', icon: 'key' }
    }]
  }, {
    path: '/system',
    component: Layout,
    // alwaysShow: true,
    // ignoreRule: true,
    redirect: 'noredirect',
    name: 'system',
    meta: { title: '系统设置', icon: 'setting' },
    children: [{
      path: 'index',
      name: 'icon',
      component: () => import('@/views/svg-icons/index'),
      meta: { title: 'icon', icon: 'icon', noCache: true }
    }, {
      path: 'user',
      hidden: process.env.NODE_ENV === 'production',
      name: 'systemUser',
      component: _import('system/user'),
      meta: { title: '用户中心', icon: 'user' }
    }, {
      path: 'test',
      name: 'test',
      component: _import('test/index'),
      meta: { title: 'test', icon: 'table' }
    }]
  }, {
    path: '*',
    hidden: true,
    redirect: '/404'
  }
]

export default new Router({
  // mode: 'history', // 后端支持可开
  scrollBehavior: () => ({ y: 0 }), // https://www.cnblogs.com/sophie_wang/p/7880261.html 载入页面时保存停留的位置的处理方法
  routes: constantRouterMap
})
