import { loginByUsername, logout } from '@/api/user'
import { cookie, removeAll } from '@/utils/cookie'
import defaultAvatar from '@/assets/default_avatar.gif'

const user = {
  state: {
    id: cookie.get_userInfo().id,
    name: cookie.get_userInfo().name,
    avatar: defaultAvatar,
    deptId: cookie.get_userInfo().deptId,
    deptName: cookie.get_userInfo().deptName,
    account: cookie.get_userInfo().account,
    roleList: cookie.get_roleList(),
    roleNames: cookie.get_userInfo().roleNames,
    aesKey: cookie.get_aesKey(),
    xToken: cookie.get_xToken()
  },

  mutations: {
    SET_ID: (state, id) => {
      state.id = id
    },
    SET_NAME: (state, name) => {
      state.name = name
    },
    SET_AVATAR: (state, avatar) => {
      state.avatar = avatar
    },
    SET_DEPTID: (state, deptId) => {
      state.deptId = deptId
    },
    SET_DEPTNAME: (state, deptName) => {
      state.deptName = deptName
    },
    SET_ACCOUNT: (state, account) => {
      state.account = account
    },
    SET_ROLELIST: (state, roleList) => {
      state.roleList = roleList
    },
    SET_ROLENAMES: (state, roleNames) => {
      state.roleNames = roleNames
    },
    SET_AESKEY: (state, aesKey) => {
      state.aesKey = aesKey
    },
    SET_XTOKEN: (state, xToken) => {
      state.xToken = xToken
    }
  },

  actions: {
    // 用户名登录
    login({ commit }, userInfo) {
      return new Promise((resolve, reject) => {
        loginByUsername(userInfo.username, userInfo.password).then(res => {
          if (res.data.code === 200) {
            const data = res.data.data
            cookie.set_userInfo(data)
            commit('SET_ID', data.id)
            commit('SET_NAME', data.name)
            commit('SET_DEPTID', data.deptId)
            commit('SET_DEPTNAME', data.deptName)
            commit('SET_ACCOUNT', data.account)
            if (data.avatar) {
              commit('SET_AVATAR', data.avatar)
            }
            if (data.roleList instanceof Array) { // 验证返回的roleList是否是数组
              cookie.set_roleList(data.roleList)
              commit('SET_ROLELIST', data.roleList)
            }
            if (data.roleNames instanceof Array) {
              commit('SET_ROLENAMES', data.roleNames)
            }
            cookie.set_aesKey(data.aesKey)
            commit('SET_AESKEY', data.aesKey)
            cookie.set_xToken(data.xToken)
            commit('SET_XTOKEN', data.xToken)
            resolve(res)
          } else {
            reject(res)
          }
        }).catch(err => {
          reject(err)
        })
      })
    },
    // 登出
    LogOut({ commit, state }) {
      return new Promise((resolve, reject) => {
        logout(state.token).then(() => {
          // commit('SET_AESKEY', '')
          // commit('SET_XTOKEN', '')
          // commit('SET_ROLELIST', [])
          // cookie.remove_aesKey()
          // cookie.remove_xToken()
          // cookie.remove_roleList()
          removeAll()
          resolve()
        }).catch(error => {
          reject(error)
        })
      })
    },
    // 前端 登出
    FedLogOut({ commit }) {
      return new Promise(resolve => {
        // commit('SET_AESKEY', '')
        // commit('SET_XTOKEN', '')
        // commit('SET_ROLELIST', [])
        // cookie.remove_aesKey()
        // cookie.remove_xToken()
        // cookie.remove_roleList()
        removeAll()
        resolve()
      })
    }
  }
}

export default user
