export function parseTime(time, cFormat) {
  if (arguments.length === 0) {
    return null
  }
  const format = cFormat || '{y}-{m}-{d} {h}:{i}:{s}'
  let date
  if (typeof time === 'object') {
    date = time
  } else {
    if (('' + time).length === 10) time = parseInt(time) * 1000
    date = new Date(time)
  }
  const formatObj = {
    y: date.getFullYear(),
    m: date.getMonth() + 1,
    d: date.getDate(),
    h: date.getHours(),
    i: date.getMinutes(),
    s: date.getSeconds(),
    a: date.getDay()
  }
  const time_str = format.replace(/{(y|m|d|h|i|s|a)+}/g, (result, key) => {
    let value = formatObj[key]
    if (key === 'a') return ['一', '二', '三', '四', '五', '六', '日'][value - 1]
    if (result.length > 0 && value < 10) {
      value = '0' + value
    }
    return value || 0
  })
  return time_str
}

export function formatTime(time, option) {
  time = +time * 1000
  const d = new Date(time)
  const now = Date.now()

  const diff = (now - d) / 1000

  if (diff < 30) {
    return '刚刚'
  } else if (diff < 3600) { // less 1 hour
    return Math.ceil(diff / 60) + '分钟前'
  } else if (diff < 3600 * 24) {
    return Math.ceil(diff / 3600) + '小时前'
  } else if (diff < 3600 * 24 * 2) {
    return '1天前'
  }
  if (option) {
    return parseTime(time, option)
  } else {
    return d.getMonth() + 1 + '月' + d.getDate() + '日' + d.getHours() + '时' + d.getMinutes() + '分'
  }
}

export function param2Obj(url) {
  const search = url.split('?')[1]
  if (!search) {
    return {}
  }
  return JSON.parse('{"' + decodeURIComponent(search).replace(/"/g, '\\"').replace(/&/g, '","').replace(/=/g, '":"') + '"}')
}

export function randomStr(length) {
  const chars = 'ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz'
  const max = chars.length
  let s = ``
  let len = length || 8
  while (len) {
    len--
    s += chars.charAt(Math.floor(Math.random() * max))
  }
  return s
}

// 状态解析
export function stateParse(array, value, key) {
  if (array && array.length > 0) {
    const temp = array.find(item => (key ? item[key] : item.value) === value)
    return temp ? temp.label : value
  } else {
    return value
  }
}

// 保留小数点四舍五入
export function toFixed(num, keep) {
  if (keep) {
    return num.toFixed(keep)
  } else if (/\.\d{3,}/.test(num)) {
    return num.toFixed(2)
  } else {
    return num
  }
}

// 字符串包含测试
export function include(query, str, disperse) {
  if (disperse === undefined || disperse) {
    if (query !== undefined && query !== null) {
      return new RegExp((query + '').split('').join('.*')).test(str + '')
    } else {
      return true
    }
  } else {
    return new RegExp(query + '').test(str + '')
  }
}
